import { useTranslation } from 'react-i18next'

import { styled } from '@mui/system'
import Box from '@mui/material/Box'
import AccountBoxOutlinedIcon from '@mui/icons-material/AccountBoxOutlined'

import { HrefButton } from 'components/button'

const StyledParagraph = styled('p')({
  fontSize: '1rem',
})

const StyledBox = styled(Box)({
  borderStyle: 'solid',
  borderColor: 'black',
  borderWidth: '2px',
  borderRadius: '1%',
  width: '24rem',
  height: '18rem',
})

interface LoginBoxProps {
  header: string
  info: string
}

export default function LoginBox({ header, info }: LoginBoxProps) {
  const { t } = useTranslation(['frontpage'])
  return (
    <StyledBox
      sx={{
        marginBottom: { xs: '2rem', md: '0rem' },
      }}
    >
      <Box
        sx={{
          display: 'flex',
          flexDirection: 'column',
          margin: '2rem',
          height: '35%',
        }}
      >
        <Box sx={{ display: 'flex', alignItems: 'center' }}>
          <AccountBoxOutlinedIcon
            fontSize="inherit"
            sx={{
              marginRight: { xs: '0rem', md: '0.5rem' },
            }}
          />
          {header}
        </Box>
        <StyledParagraph>{info}</StyledParagraph>
      </Box>
      <Box sx={{ display: 'flex', margin: '2rem' }}>
        <HrefButton to="/oidc/authenticate/">
          <Box sx={{ margin: '0 2rem 0 2rem' }}>{t('login')}</Box>
        </HrefButton>
      </Box>
    </StyledBox>
  )
}
