import React from 'react'
import { Helmet } from 'react-helmet'
import { useTranslation } from 'react-i18next'

import { styled } from '@mui/material/styles'
import { Container } from '@mui/material'
import { appInst } from 'appConfig'

const StyledPageHeader = styled('h2')(({ theme }) => ({
  color: theme.greg.textWhite,
  fontSize: '3rem',
  fontWeight: 'bold',
  margin: '1rem 0 1rem 0',
}))

interface IPage {
  children: React.ReactNode
  header?: string
}

let faviconPath = ''

switch (appInst) {
  case 'uib':
    faviconPath = 'favicons/uib.ico'
    break
  case 'uio':
    faviconPath = 'favicons/uio.svg'
    break
  default:
    faviconPath = 'favicons/uio.svg'
}

export default function Page(props: IPage) {
  const { header, children } = props
  const { i18n, t } = useTranslation()
  const appTitle = t('common:header:applicationTitle')

  return (
    <>
      <Helmet titleTemplate={`%s - ${appTitle}`} defaultTitle={appTitle}>
        <link rel="icon" href={faviconPath} />
        <html lang={i18n.language} />
        <title>{header}</title>
      </Helmet>
      <Container
        maxWidth="md"
        sx={{ paddingBottom: '2rem', paddingTop: '2rem' }}
      >
        {header ? <StyledPageHeader>{header}</StyledPageHeader> : <></>}
        {children}
      </Container>
    </>
  )
}

Page.defaultProps = {
  header: null,
}
