import PersonIcon from '@mui/icons-material/Person'
import { Box, IconButton, Theme } from '@mui/material'
import PersonAddIcon from '@mui/icons-material/PersonAdd'
import React from 'react'
import { useTranslation } from 'react-i18next'
import { useHistory } from 'react-router-dom'

interface SponsorGuestButtonsProps {
  yourGuestsActive?: boolean
  registerNewGuestActive?: boolean
}

export default function SponsorGuestButtons(props: SponsorGuestButtonsProps) {
  const { yourGuestsActive, registerNewGuestActive } = props
  const { t } = useTranslation(['common'])
  const history = useHistory()

  const goToOverview = () => {
    history.push('/sponsor')
  }

  const goToRegister = () => {
    history.push('/register')
  }

  return (
    <Box
      sx={{
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'space-evenly',
        marginBottom: '2rem',
      }}
    >
      <IconButton
        onClick={goToOverview}
        sx={{
          display: 'flex',
          flexDirection: 'column',
          alignItems: 'center',
          typography: 'caption',
          textDecorationLine: () => (yourGuestsActive ? 'underline' : ''),
        }}
      >
        <PersonIcon
          fontSize="large"
          sx={{
            borderRadius: '2rem',
            borderStyle: 'solid',
            borderColor: (theme: Theme) =>
              yourGuestsActive
                ? theme.palette.secondary.main
                : theme.greg.deactivatedColor,
            fill: 'white',
            backgroundColor: (theme: Theme) =>
              yourGuestsActive
                ? theme.palette.secondary.main
                : theme.greg.deactivatedColor,
          }}
        />
        {t('yourGuests')}
      </IconButton>

      <IconButton
        onClick={goToRegister}
        sx={{
          display: 'flex',
          flexDirection: 'column',
          alignItems: 'center',
          typography: 'caption',
          textDecorationLine: () => (registerNewGuestActive ? 'underline' : ''),
        }}
      >
        <PersonAddIcon
          fontSize="large"
          sx={{
            borderRadius: '2rem',
            borderStyle: 'solid',
            borderColor: (theme: Theme) =>
              registerNewGuestActive
                ? theme.palette.secondary.main
                : theme.greg.deactivatedColor,
            fill: 'white',
            backgroundColor: (theme: Theme) =>
              registerNewGuestActive
                ? theme.palette.secondary.main
                : theme.greg.deactivatedColor,
          }}
        />
        {t('registerNewGuest')}
      </IconButton>
    </Box>
  )
}

SponsorGuestButtons.defaultProps = {
  yourGuestsActive: false,
  registerNewGuestActive: false,
}
