import React from 'react'
import fetchMock, { enableFetchMocks } from 'jest-fetch-mock'
import { render, screen } from 'test-utils'
import AdapterDateFns from '@mui/lab/AdapterDateFns'
import { LocalizationProvider } from '@mui/lab'
import GuestRegister from './index'

enableFetchMocks()

const testData = {
  person: {
    first_name: 'Test20',
    last_name: 'Tester',
    mobile_phone: '+4797543910',
    email: 'test@example.org',
    fnr: '04062141242',
    passport: 'DK-123456',
    date_of_birth: '1995-02-25',
  },
  role: {
    ou_name_en: 'English organizational unit name',
    ou_name_nb: 'Norsk navn organisasjonsenhet',
    role_name_en: 'Guest role',
    role_name_nb: 'Gjesterolle',
    start: '2021-08-10',
    end: '2021-08-16',
    contact_person_unit: 'Test contact person',
    comments: 'Test comment',
  },
  meta: {
    session_type: 'invite',
  },
}

beforeEach(() => {
  fetchMock.mockIf('/api/ui/v1/invited/', () =>
    Promise.resolve<any>(JSON.stringify(testData))
  )
})

test('Field showing values correctly', async () => {
  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegister />
    </LocalizationProvider>
  )

  await screen.findByDisplayValue(testData.person.first_name)
  await screen.findByDisplayValue(testData.person.last_name)
  await screen.findByDisplayValue(testData.person.email)
  await screen.findByDisplayValue(testData.person.fnr)

  // Passport nationality. The i18n-mock sets up en as the i18n.language property, so look for the English name
  await screen.findByText('Denmark')
  await screen.findByDisplayValue('123456')
  await screen.findByDisplayValue(testData.person.date_of_birth)

  // Mobile phone country code
  await screen.findByDisplayValue('NO')
  await screen.findByDisplayValue('97543910')

  // Role information
  await screen.findByDisplayValue(testData.role.ou_name_en)
  // TODO Haven't been able to mock getting role types properly yet, so not checking role name
  // await screen.findByDisplayValue(testData.role.name_en)
  await screen.findByDisplayValue(
    `${testData.role.start} - ${testData.role.end}`
  )
  await screen.findByDisplayValue(testData.role.comments)
})
