from rest_framework import serializers
from rest_framework.fields import BooleanField, CharField, SerializerMethodField

from greg.api.serializers.consent import ConsentSerializerBrief
from greg.api.serializers.identity import IdentitySerializer, SpecialIdentitySerializer
from greg.api.serializers.role import RoleSerializer, SpecialRoleSerializer
from greg.models import Person, Identity


class PersonSerializer(serializers.ModelSerializer):
    identities = IdentitySerializer(many=True, read_only=True)
    roles = RoleSerializer(many=True, read_only=True)
    consents = ConsentSerializerBrief(many=True, read_only=True)

    class Meta:
        model = Person
        fields = [
            "id",
            "first_name",
            "last_name",
            "date_of_birth",
            "registration_completed_date",
            "identities",
            "roles",
            "consents",
        ]


class SpecialPersonSerializer(serializers.ModelSerializer):
    """
    Serializer for the person endpoint

    Can be used to change or add an email to the person

    """

    pid = CharField(source="id", read_only=True)
    first = CharField(source="first_name", read_only=True)
    last = CharField(source="last_name", read_only=True)
    email = SerializerMethodField(source="private_email")
    mobile = SerializerMethodField(source="private_mobile", read_only=True)
    fnr = SpecialIdentitySerializer(read_only=True)
    passport = SpecialIdentitySerializer(read_only=True)
    active = SerializerMethodField(source="active", read_only=True)
    registered = BooleanField(source="is_registered", read_only=True)
    verified = BooleanField(source="is_verified", read_only=True)
    roles = SpecialRoleSerializer(many=True, read_only=True)

    def get_email(self, obj):
        return obj.private_email and obj.private_email.value

    def get_mobile(self, obj):
        return obj.private_mobile and obj.private_mobile.value

    def get_active(self, obj):
        return obj.is_registered and obj.is_verified

    class Meta:
        model = Person
        fields = [
            "pid",
            "first",
            "last",
            "mobile",
            "fnr",
            "email",
            "passport",
            "active",
            "registered",
            "verified",
            "roles",
        ]


class PersonSearchSerializer(serializers.ModelSerializer):
    pid = CharField(source="person.id")
    first = CharField(source="person.first_name")
    last = CharField(source="person.last_name")

    class Meta:
        model = Identity
        fields = ["pid", "first", "last", "value", "type"]
