import pytest

from rest_framework.reverse import reverse

from greg.models import Identity
from gregui.models import GregUserProfile


@pytest.mark.django_db
def test_identity_get(client, log_in, user_sponsor, person_foo):
    log_in(user_sponsor)
    response = client.get(
        reverse("gregui-v1:identity-detail", kwargs={"pk": person_foo.fnr.id})
    )
    assert response.status_code == 200
    content = response.json()
    assert content["person"] == person_foo.id


@pytest.mark.django_db
def test_identity_patch(client, log_in, user_sponsor, person_foo):
    log_in(user_sponsor)
    ident = Identity.objects.get(pk=person_foo.fnr.id)
    assert not ident.verified

    client.patch(
        reverse("gregui-v1:identity-detail", kwargs={"pk": person_foo.fnr.id}),
        data={},
    )
    ident.refresh_from_db()
    assert ident.verified == Identity.Verified.MANUAL
    assert ident.verified_by == GregUserProfile.objects.get(user=user_sponsor).sponsor
